# /test/__init__.py
#
# See /LICENCE.md for Copyright information
"""Entry point for tests."""

import os

os.environ["JOBSTAMPS_DISABLED"] = "1"
